@@ -47,7 +47,9 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
         self.connected = False
         self.username = None
         self.sendReceipts = True
+        self.sendRead = True
         self.disconnectAction = self.__class__.DISCONNECT_ACTION_PROMPT
+        self.credentials = None
 
         #add aliases to make it user to use commands. for example you can then do:
         # /message send foobar "HI"
@@ -77,6 +79,9 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
 
         return "%s@s.whatsapp.net" % number
 
+    def setCredentials(self, username, password):
+        self.getLayerInterface(YowAuthenticationProtocolLayer).setCredentials(username, password)
+
     def onEvent(self, layerEvent):
         if layerEvent.getName() == self.__class__.EVENT_START:
             self.startInput()
@@ -219,6 +224,35 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
         else:
             logger.error("Python PIL library is not installed, can't set profile picture")
 
+    @clicmd("Get profile privacy")
+    def profile_getPrivacy(self):
+        if self.assertConnected():
+            def onSuccess(resultIqEntity, originalIqEntity):
+                self.output("Profile privacy is: %s" %(resultIqEntity))
+
+            def onError(errorIqEntity, originalIqEntity):
+                logger.error("Error getting profile privacy")
+
+            iq = GetPrivacyIqProtocolEntity()
+            self._sendIq(iq, onSuccess, onError)
+
+    @clicmd("Profile privacy. value=all|contacts|none names=profile|status|last. Names are comma separated, defaults to all.")
+    def profile_setPrivacy(self, value="all", names=None):
+        if self.assertConnected():
+            def onSuccess(resultIqEntity, originalIqEntity):
+                self.output("Profile privacy set to: %s" %(resultIqEntity))
+
+            def onError(errorIqEntity, originalIqEntity):
+                logger.error("Error setting profile privacy")
+            try:
+                names = [name for name in names.split(',')] if names else None
+                iq = SetPrivacyIqProtocolEntity(value, names)
+                self._sendIq(iq, onSuccess, onError)
+            except Exception as inst:
+                self.output(inst.message)
+                return self.print_usage()
+
+
     ########### groups
 
     @clicmd("List all groups you belong to", 5)
@@ -391,6 +425,12 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
             entity = OutgoingChatstateProtocolEntity(ChatstateProtocolEntity.STATE_TYPING, self.aliasToJid(jid))
             self.toLower(entity)
 
+    @clicmd("Request contacts statuses")
+    def statuses_get(self, contacts):
+        if self.assertConnected():
+            entity = GetStatusesIqProtocolEntity([self.aliasToJid(c) for c in contacts.split(',')])
+            self.toLower(entity)
+
     @clicmd("Send paused state")
     def state_paused(self, jid):
         if self.assertConnected():
@@ -406,23 +446,20 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
     @clicmd("Disconnect")
     def disconnect(self):
         if self.assertConnected():
+
             self.broadcastEvent(YowLayerEvent(YowNetworkLayer.EVENT_STATE_DISCONNECT))
 
     @clicmd("Quick login")
     def L(self):
-        return self.login(*self.getProp(YowAuthenticationProtocolLayer.PROP_CREDENTIALS))
+        if self.connected:
+            return self.output("Already connected, disconnect first")
+        self.getLayerInterface(YowNetworkLayer).connect()
+        return True
 
     @clicmd("Login to WhatsApp", 0)
     def login(self, username, b64password):
-
-        if self.connected:
-            return self.output("Already connected, disconnect first")
-
-        self.getStack().setProp(YowAuthenticationProtocolLayer.PROP_CREDENTIALS, (username, b64password))
-        connectEvent = YowLayerEvent(YowNetworkLayer.EVENT_STATE_CONNECT)
-        self.broadcastEvent(connectEvent)
-        return True #prompt will wait until notified
-
+        self.setCredentials(username, b64password)
+        return self.L()
 
     ######## receive #########
 
@@ -491,8 +528,8 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
 
         self.output(output, tag = None, prompt = not self.sendReceipts)
         if self.sendReceipts:
-            self.toLower(message.ack())
-            self.output("Sent delivered receipt", tag = "Message %s" % message.getId())
+            self.toLower(message.ack(self.sendRead))
+            self.output("Sent delivered receipt"+" and Read" if self.sendRead else "", tag = "Message %s" % message.getId())
 
 
     def getTextMessageBody(self, message):
@@ -503,7 +540,7 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
             return self.getDownloadableMediaMessageBody(message)
         else:
             return "[Media Type: %s]" % message.getMediaType()
-       
+
 
     def getDownloadableMediaMessageBody(self, message):
          return "[Media Type:{media_type}, Size:{media_size}, URL:{media_url}]".format(
@@ -569,4 +606,3 @@ class YowsupCliLayer(Cli, YowInterfaceLayer):
     @clicmd("Print this message")
     def help(self):
         self.print_usage()
-    
