@@ -1,4 +1,4 @@
 from .env_android import AndroidYowsupEnv
 from .env_s40 import S40YowsupEnv
 
-CURRENT_ENV = AndroidYowsupEnv()
+CURRENT_ENV = S40YowsupEnv()
