@@ -3,4 +3,6 @@ from .challenge import ChallengeProtocolEntity
 from .response import ResponseProtocolEntity
 from .stream_features import StreamFeaturesProtocolEntity
 from .success import SuccessProtocolEntity
-from .failure import FailureProtocolEntity
\ No newline at end of file
+from .failure import FailureProtocolEntity
+from .stream_error_conflict import StreamErrorConflictProtocolEntity
+from .stream_error_ack import StreamErrorAckProtocolEntity
