@@ -1,8 +1,9 @@
 from yowsup.layers.auth.protocolentities.failure import FailureProtocolEntity
 from yowsup.structs import ProtocolTreeNode
 from yowsup.structs.protocolentity import ProtocolEntityTest
+import unittest
 
-class FailureProtocolEntityTest(ProtocolEntityTest):
+class FailureProtocolEntityTest(ProtocolEntityTest, unittest.TestCase):
     def setUp(self):
         self.ProtocolEntity = FailureProtocolEntity
         self.node = ProtocolTreeNode("failure", {}, [ProtocolTreeNode("not-authorized", {})])
\ No newline at end of file
