@@ -1,8 +1,9 @@
 from yowsup.layers.auth.protocolentities.success import SuccessProtocolEntity
 from yowsup.structs import ProtocolTreeNode
 from yowsup.structs.protocolentity import ProtocolEntityTest
+import unittest
 
-class SuccessProtocolEntityTest(ProtocolEntityTest):
+class SuccessProtocolEntityTest(ProtocolEntityTest, unittest.TestCase):
     def setUp(self):
         self.ProtocolEntity = SuccessProtocolEntity
         attribs = {
