@@ -5,3 +5,5 @@ from .notification_contact_add import AddContactNotificationProtocolEntity
 from .notification_contact_remove import RemoveContactNotificationProtocolEntity
 from .notification_contact_update import UpdateContactNotificationProtocolEntity
 from .notificiation_contacts_sync import ContactsSyncNotificationProtocolEntity
+from .iq_statuses_get import GetStatusesIqProtocolEntity
+from .iq_statuses_result import ResultStatusesIqProtocolEntity
