@@ -3,3 +3,6 @@ from .iq_result import ResultIqProtocolEntity
 from .iq_ping import PingIqProtocolEntity
 from .iq_result_pong import PongResultIqProtocolEntity
 from .iq_error import ErrorIqProtocolEntity
+from .iq_push import PushIqProtocolEntity
+from .iq_props import PropsIqProtocolEntity
+from .iq_crypto import CryptoIqProtocolEntity
