@@ -10,5 +10,5 @@ class DownloadableMediaMessageProtocolEntityTest(MediaMessageProtocolEntityTest)
         mediaNode.setAttribute("filehash",  "FILEHASH")
         mediaNode.setAttribute("url",       "URL")
         mediaNode.setAttribute("ip",        "IP")
-        mediaNode.setAttribute("size",      "SIZE")
+        mediaNode.setAttribute("size",      "123")
         mediaNode.setAttribute("file",      "FILE")
