@@ -1,8 +1,9 @@
 from yowsup.layers.protocol_messages.protocolentities.message import MessageProtocolEntity
 from yowsup.structs import ProtocolTreeNode
 from yowsup.structs.protocolentity import ProtocolEntityTest
+import unittest
 
-class MessageProtocolEntityTest(ProtocolEntityTest):
+class MessageProtocolEntityTest(ProtocolEntityTest, unittest.TestCase):
     def setUp(self):
         self.ProtocolEntity = MessageProtocolEntity
         # ORDER_MATTERS for node.toString() to output return attribs in same order
