@@ -1,4 +1,6 @@
 from yowsup.structs import ProtocolEntity, ProtocolTreeNode
+from yowsup.layers.protocol_receipts.protocolentities  import OutgoingReceiptProtocolEntity
+
 class NotificationProtocolEntity(ProtocolEntity):
     '''
     <notification offline="0" id="{{NOTIFICATION_ID}}" notify="{{NOTIFY_NAME}}" type="{{NOTIFICATION_TYPE}}" 
@@ -23,8 +25,8 @@ class NotificationProtocolEntity(ProtocolEntity):
         out += "Type: %s\n" % self.getType()
         return out
 
-    def getFrom(self):
-        return self._from
+    def getFrom(self, full = True):
+        return self._from if full else self._from.split('@')[0]
 
     def getType(self):
         return self._type
@@ -47,6 +49,9 @@ class NotificationProtocolEntity(ProtocolEntity):
        
         return self._createProtocolTreeNode(attribs, children = None, data = None)
 
+    def ack(self):
+        return OutgoingReceiptProtocolEntity(self.getId(), self.getFrom())
+
     @staticmethod
     def fromProtocolTreeNode(node):
         return NotificationProtocolEntity(
